*===================================================================================*
* T͍TULO DE LA SINTAXIS:													    	*
* Clculo de Indice de Pobreza Multidimensional - IPM	   							*
* OPERACIN ESTADSTICA:													  		*
* Encuesta Nacional de Empleo, Desempleo y Subempleo (ENEMDU) 				   		*
* UNIDAD TCNICA RESPONSABLE: 												  		*
* Direccin de Innovacin en Mtricas y Metodologas (DINME)			   			*
* ENTIDAD EJECUTORA:														   		*
* Instituto Nacional de Estadstica y Censos (INEC)							   		*
*===================================================================================*
* Fecha de elaboracin:        12 de Noviembre del 2015					   			*
* Fecha ltima modificacin:   26 de Enero del 2016						   			*
*===================================================================================*
* Elaborado por:																	*
* Fausto Jcome, Roberto Castillo, Jos Andrade, Cristina Restrepo y Melody Serrano *
*===================================================================================*
* Revisado por:																  		*
* Equipo Tcnico de la Comisin Especial de Estadstica de Pobreza					*
* Oxford Poverty & Human Development Iniciative										*
*===================================================================================*
* Aprobado por:																  		*
* Roberto Castillo A.														   		*
* Director de Innovacin en Mtricas y Metodologas (DINME)				   			*
* Instituto Nacional de Estadstica y Censos (INEC)							   		*
* roberto_castillo@inec.gob.ec												   		*
*===================================================================================*

*===================================================================================*
* Instrucciones:
* 1. Descargar las bases de la pgina:
*    www.ecuadorencifras.gob.ec/banco-de-informacion/
*    Pestaa 	-Investigacin: Todas
*	    		-Tipo de archivo: Bases
*		    	-Archivo: 
*					 Producto - Encuesta Nacional de Empleo Desempleo Subempleo
*					 Tipo de encuesta - 15 aos
*					 Perodo - Trimestral
*					 Archivo - bdd_enemdu_15anios_12_(seleccionar ao)
* 2. Transformar las bases de personas (*12_enemdubdd_15anios) y vivienda 
*    (*12_enemdubdd_viviendahogar) de SPSS (*.sav) a formato STATA (*.dta).
*	 En caso de tener problemas, revisar el manual de la sintaxis del IPM.
* 3. Guardar en un directorio y copiar ese directorio en "cd".
* 4. Correr la programacin en stata.
*===================================================================================*

clear all
set more off

* Cambiar Directorio
cd "C:\..."

* Atencin.- No modificar el nombre de las bases descargadas

* Nombre de la base de PERSONAS descargada
loc bdd_per "*12_enemdubdd_15anios"	//reemplazar asterisco por el ao
* Nombre de la base de VIVIENDA descargada
loc bdd_viv "*12_enemdubdd_viviendahogar" //reemplazar asterisco por el ao	

*===================================================================================*
* PREPARACIN DE LA BASE DE TRABAJO
*===================================================================================*
* Unir bases de personas y hogares
loc bdd=substr("`bdd_per'",1,4)
loc n1=1
foreach base in `bdd_per' `bdd_viv' {
use `base', clear
cap drop id_upm 
cap drop id_hogar 

if `n1'==1 loc varid "ciudad zona sector panelm vivienda hogar p01"
else	   loc varid "ciudad zona sector panelm vivienda hogar"

	foreach var of loc varid {
	tempvar largo
	tostring `var', replace force
	gen `largo'=length(`var')
	sum `largo'
	replace `var'=substr(string(10^(r(max)-`largo')),2,.)+`var' if r(max)>`largo'
	drop `largo'
	}
* Creacin de identificadores nicos
egen id_hogar = concat(ciudad zona sector panelm vivienda hogar), punct("-")
label var id_hogar "Identificador hogar"
if `n1'==1 {
egen id_per=    concat(ciudad zona sector panelm vivienda hogar p01), punct("-")
label var id_per "Identificador persona"
}
destring `varid', replace
tempfile bdd`n1'
save `bdd`n1++'', replace
}
use `bdd1', clear
merge m:1 id_hogar using `bdd2', keep(1 3) nogen

*===================================================================================*
* A. CREACIN DE DIMENSIONES E INDICADORES
*===================================================================================*

*===================================================================================*
* DIMENSION 1: EDUCACIN
*===================================================================================*

*===================================================================================*
* 1. Inasistencia a educacin bsica y bachillerato
*===================================================================================*
/* 
Poblacin de referencia: Nios (5-14 aos) y Adolescentes (15-17 aos)
Privacin:
( 5-14 aos): No asiste a centro de educacin bsica.
(15-17 aos): Complet educacin bsica y no asiste al bachillerato.
*/

* a) Asistencia a educacin bsica
# delimit;
gen     asist_basica=1 if inrange(p03,5,14) & (p07==1) & 
(  inlist(p10a,1,3)
| (p10a==4 & inrange(p10b,0,6)) 
| (p10a==5 & inrange(p10b,0,9)) 
| (p10a==6 & inrange(p10b,0,2)));
# delimit cr
replace asist_basica=0 if inrange(p03,5,14) & asist_basica!=1
label var asist_basica "Asistencia a educacin bsica"

* b) Asistencia a educacin bachillerato
# delimit;
gen     asist_bach=1 if inrange(p03,15,17) & (p07==1)  & 
( (p10a==5 & p10b==10)
| (p10a==7 & inrange(p10b,0,2)) 
| (p10a==6 & inrange(p10b,3,5)));
# delimit cr
replace asist_bach=0 if inrange(p03,15,17) & asist_bach!=1 
label var asist_bach "Asistencia a educacin bachillerato"

* c) Clculo de la privacin  																		
gen  	dim1_ind1=1 if inrange(p03,5,17) & p10a<8 
replace dim1_ind1=0 if inrange(p03,5,17) & (asist_basica==1 | asist_bach==1 | p10a>=8)
label var dim1_ind1 "Inasistencia a educacin bsica y bachillerato"

*===================================================================================*
* 2. No acceso a educacin superior por razones econmicas
*===================================================================================*
/* 
Poblacin de referencia: Jvenes (18-29 aos) bachilleres.
Privacin: 
No asiste a un establecimiento de educacin superior por falta de recursos econmicos.
*/

# delimit;																			
gen     dim1_ind2=0 if inrange(p03,18,29) & (p07>=1 & p07<=2) &
( (p10a==7 & p10b>=3) 
| (p10a==6 & p10b>=6)) 
| inrange(p10a,8,10); 
# delimit cr 

# delimit;																			
replace   dim1_ind2=1 if inrange(p03,18,29) & p07==2 &
( (p10a==7 & p10b>=3) 
| (p10a==6 & p10b>=6) 
| (inrange(p10a,8,9)))
& p09==3 ; 
# delimit cr 
replace   dim1_ind2=. if p03<18 | p03>29
label var dim1_ind2 "No acceso a educacin superior por razones econmicas"

*===================================================================================*
* 3. Logro educativo incompleto
*===================================================================================*
/*
Poblacin de referencia: Personas de 18 a 64 aos.
Privacin: 
Personas con menos de 10 aos de escolaridad que no asisten
a centros de educacin formal.
*/

* a) Aos promedio de escolaridad
gen     escol=.
replace escol=0 	  if p10a==1 & p10b==0
replace escol=0 	  if p10a==2 & p10b==0 
replace escol=2 	  if p10a==2 & p10b==1
replace escol=4 	  if p10a==2 & p10b==2
replace escol=6 	  if p10a==2 & p10b==3
replace escol=7 	  if p10a==2 & p10b==4
replace escol=1 	  if p10a==3
replace escol=1+ p10b if p10a==4
replace escol=   p10b if p10a==5
replace escol=7+ p10b if p10a==6
replace escol=10+p10b if p10a==7
replace escol=13+p10b if p10a==8
replace escol=13+p10b if p10a==9
replace escol=18+p10b if p10a==10
replace escol=0 	  if escol==.

* b) Clculo de la privacin
gen     dim1_ind3=0 if inrange(p03,18,64) & ((escol<10 & p07==1) | (escol>=10))
replace dim1_ind3=1 if inrange(p03,18,64) &   escol<10 & p07==2
label var dim1_ind3 "Logro educativo incompleto"

*===================================================================================*
* DIMENSION 2: TRABAJO Y SEGURIDAD SOCIAL
*===================================================================================*

*===================================================================================*
* 1. Empleo infantil y adolescente
*===================================================================================*
/* 
Poblacin de referencia: Nios (5-14 aos) y Adolescentes (15-17 aos)
Privacin: 
Nios (5-14 aos): Ocupado en la semana de referencia
Adolescentes (15-17 aos): Ocupado en la semana de referencia y cumple una 
de las siguientes condiciones:
i)  Recibe una remuneracin inferior al Salario Bsico Unificado
ii) No asisten a clases
iii)Trabaja ms de 30 horas.
*/

gen     horas =0 if empleo ==1
replace horas =p24 if pea ==1 & p20 ==1
replace horas =p24 if pea ==1 & p20 ==2 & p21 <=11
recode p51* (999 = .)
egen hh = rowtotal (p51*), missing
replace hh  = . if hh <0
replace horas = hh if pea ==1 & p20 ==2 & p21 ==12 & p22==1

gen     dim2_ind1=(p20==1 | inrange(p21,1,11) | p22==1) & inrange(p03, 5,14)
replace dim2_ind1=1 if inrange(condactn,2,6) & inrange(p03,15,17)
replace dim2_ind1=1 if         condactn ==1  & inrange(p03,15,17) & (p07==2 | horas>30)
replace dim2_ind1=. if p03>=18													
label var dim2_ind1 "Empleo infantil y adolescente"

*===================================================================================*
* 2. Desempleo o empleo inadecuado
*===================================================================================*
/* 
Poblacin de referencia: Poblacin de 18 aos y ms.
Privacin:
Personas en condicin de desempleo o empleo inadecuado.
*/

gen     dim2_ind2= inrange(condactn,2,8) & inrange(p03,18,98)
replace dim2_ind2=. if p03<18 | p03==99 | ///
        (p20==. & p21==. & p22==. & p32==. & p34==. & p35==.)
label var dim2_ind2 "Desempleo o empleo inadecuado"

*===================================================================================*
* 3. No contribucin al sistema de pensiones
*===================================================================================*
/* 
Poblacin de referencia: Personas de 15 aos y ms.
Privacin: 
Ocupados que no contribuyen al sistema de seguridad social. Se excluye a ocupados
de 65 aos y ms, que no aportan, pero reciben pensin por jubilacin.
Desocupados e inactivos mayores de 65 aos que:
No recibe pensin por jubilacin, BDH y Bono Joaqun Gallegos Lara (BJGL). 
*/

if `bdd'==2009 replace p77=2 // El BJGL se crea en 2010 (decreto ejecutivo N422)

* Personas ocuapadas
gen     dim2_ind3 = (empleo==1 & inrange(p05a,5,10) & inrange(p05b,5,10))
replace dim2_ind3 = 0 if empleo ==1 & p03>=65 & p72a==1

* Personas desocupadas o PEI mayores de 65 aos 
replace dim2_ind3 = 1 if (desem ==1 | pei==1) & p03>=65 & p72a==2
replace dim2_ind3 = 0 if p03>=65 & p72a== 2 & p75==1
replace dim2_ind3 = 0 if pet ==1 & p77==1
replace dim2_ind3 = . if pet ==0 | inrange(p03,0,14)

label var dim2_ind3 "No contribucin al sistema de pensiones"

*===================================================================================*
* DIMENSION 3: SALUD, AGUA Y ALIMENTACIN
*===================================================================================*

*===================================================================================*
* 1. Pobreza extrema por ingresos
*===================================================================================*
/* 
Poblacin de referencia: Toda la poblacin.
Privacin: 
Ingreso per cpita familiar es inferior al de la lnea de pobreza extrema.
*/

* Estimacin de la tasa de pobreza extrema
gen       dim3_ind1 = epobre
label var dim3_ind1 "Pobreza extrema por ingresos"

*===================================================================================*
* 2. Sin servicio de agua por red pblica
*===================================================================================*
/*
Poblacin de referencia: Toda la poblacin.
Privacin: 
Viviendas que obtienen el agua por un medio distinto al de la red pblica
*/

gen     dim3_ind2=(vi10!=1) 
replace dim3_ind2=. if vi10 ==.
label var dim3_ind2 "Sin servicio de agua por red pblica"

*===================================================================================*
* DIMENSION 4: HABITAT, VIVIENDA Y AMBIENTE SANO
*===================================================================================*

*===================================================================================*
* 1. Hacinamiento
*===================================================================================*
/* 
Poblacin de referencia: Toda la poblacin.
Privacin: 
El nmero de personas por dormitorio exclusivo para dormir mayor a tres.
*/

recode vi07 (0=1)
egen hsize=count(p01), by(id_hogar)
gen 	dim4_ind1=1 if (hsize/vi07)> 3
replace dim4_ind1=0	if (hsize/vi07)<=3
label var dim4_ind1 "Hacinamiento"

*===================================================================================*
* 2. Dficit habitacional
*===================================================================================*
/* 
Poblacin de referencia: Toda la poblacin
Privacin:
Se consideran en dficit habitacional las personas cuya vivienda, debido a los
materiales o estado de sus paredes, piso y techo, son consideradas en dficit
cualitativo  o cuantitativo .
*/

* Material y condicin del techo
# delimit ;	
    gen techo=1 if
	((vi03a==1 & inrange(vi03b,1,2))	
	|(vi03b==1 & inrange(vi03a,2,4)))	
	;	
	replace techo=2 if
	((vi03a==1 & vi03b==3)
	| vi03b==2 & inrange(vi03a,2,4))
	;	
	replace techo=3 if
	((vi03b==3 & inrange(vi03a,2,4))
	|(vi03a==5 | vi03a==6))
	;
    # delimit cr
	 
* Material y condicin de las paredes
	# delimit ;
	gen pared=1 if 
	((vi05a==1 & inrange(vi05b,1,2))
	|(vi05a==2 & vi05b==1))
	;
	replace pared=2 if
	((vi05a==1 & vi05b==3)
	|(vi05a==2 & vi05b==2)
	|(inrange(vi05a,3,5) & inrange(vi05b,1,2))) 
	;
	replace pared=3 if
	 ((vi05b==3 & inrange(vi05a,2,5))
	|(vi05a==6 | vi05a==7))     
	;
    # delimit cr
	
* Material y condicin del piso
	# delimit ;
	gen     piso=1 if
	((vi04a<=3 & vi04b==1)
	|(vi04a<=3 & vi04b==2)
	|(vi04b==1 & inrange(vi04a,4,5)))	
	;
    replace piso=2 if
	((vi04a <= 3 & vi04b == 3)
	|(vi04b==2 & inrange(vi04a,4,5))	
	|(vi04a==6 & vi04b==1))
	;
	replace piso=3 if
	((vi04b==3 & inlist(vi04a,4,5,6))
	|(vi04a==6 & vi04b==2)
	|(vi04a==7 | vi04a==8))
	;
	# delimit cr
		
* Tipologa de Vivienda
	# delimit ;
	gen     tipviv=1 if
	((techo==1 & pared==1 & inrange(piso,1,3))
	|(techo==1 & pared==2 & piso==1))
	;
	replace tipviv=2 if
	((techo==1 & pared==2 & inrange(piso,2,3))
	| techo==1 & pared==3 & inrange(piso,1,2)
    | techo==2 & pared==1 & inrange(piso,1,2)
	| techo==2 & pared==2 & inrange(piso,1,2)
	| techo==3 & pared==1 & inrange(piso,1,2)
	|(techo==3 & pared==2 & piso==1))
	;
	replace tipviv=3 if	
	((techo==1 & pared==3 & piso==3)
	|(techo==2 & pared==1 & piso==3)
	|(techo==2 & pared==2 & piso==3)
	| techo==2 & pared==3 & inrange(piso,1,3)
	|(techo==3 & pared==1 & piso==3)
	| techo==3 & pared==2 & inrange(piso,1,3)
	| techo==3 & pared==3 & inrange(piso,1,3))
	;
	# delimit cr
		
label define tipviv 1 "Aceptables" 2 "Recuperables" 3 "Irrecuperables"
label values tipviv tipviv

* Personas que habitan en viviendas con dficit habitacional
    gen dim4_ind2=1 if (tipviv==3 | tipviv==2)
replace dim4_ind2=0 if  tipviv==1
label var dim4_ind2 "Dficit habitacional"
		
*===================================================================================*
* 3. Sin saneamiento de excretas
*===================================================================================*
/*
Poblacin de referencia: Toda la poblacin.
Privacin: 
rea urbana:Vivienda con inodoro conectado a pozo sptico, pozo ciego, letrina 
		     o no tiene ningn servicio higinico.
rea rural: Vivienda con inodoro conectado a pozo ciego, letrina o no tiene 
			ningn servicio hignico.
*/

gen 	dim4_ind3=(area==1 & inrange(vi09,2,5)) | (area==2 & inrange(vi09,3,5))
replace	dim4_ind3=. if vi09==. | area==.
label var dim4_ind3 "Sin saneamiento de excretas"

*===================================================================================*
* 4. Sin servicio de recoleccin de basura
*===================================================================================*
/* 
Poblacin de referencia: Toda la poblacin.
Privacin: El hogar no cuenta con servicio municipal para eliminacin de basura.
*/

gen 	dim4_ind4=inlist(vi13,1,3,4,5)
replace dim4_ind4=. if vi13==.
label var dim4_ind4 "Sin servicio de recoleccin de basura"

*===================================================================================*
* B. IDENTIFICACIN Y AGREGACIN DE PRIVACIONES 					
*===================================================================================*

foreach var of varlist dim* {
rename `var' `var'_p
bys id_hogar: egen `var'_h=max(`var'_p)
local a: variable label `var'_p
label variable `var'_p "`a' -grupo especfico"
label variable `var'_h "`a' -nivel de hogar"
order `var'_p `var'_h, last
}
recode dim*_h (.=0)

tempfile bdd3 bddf 
save `bdd3', replace

/* Tratamiento de valores extremos: Se excluyen hogares de la muestra si no
   pueden ser evaluados - Missing data*/

*1.Educacin*
egen miss_dim1_ind1=rowmiss(p07 p10a) if inrange(p03,5,17)
egen miss_dim1_ind2=rowmiss(p07 p10a) if inrange(p03,18,29)
egen miss_dim1_ind3=rowmiss(p07 escol) if inrange(p03,18,64)

*2.Trabajo y seguridad social*
gen 	miss_dim2_ind1=(p20==. & p21==. & p22==.) if inrange(p03,5,14)
replace miss_dim2_ind1=1 if condactn==. & inrange(p03,15,17)
replace miss_dim2_ind1=1 if condactn==1 & inrange(p03,15,17) & (p07==. | horas==.)
egen    miss_dim2_ind2=rowmiss(condactn) if inrange(p03,18,98)
replace miss_dim2_ind2=1 if p20==. & p21==. & p22==. & p32==. & p34==. & p35==. & ///
inrange(p03,18,98)
egen    miss_dim2_ind3=rowmiss(p72a p75 p77 p05a p05b) if inrange(p03,15,98)

*3.Salud, agua y alimentacin*
egen miss_dim3_ind1=rowmiss(epobre)
egen miss_dim3_ind2=rowmiss(vi10)

*4.Hbitat, vivienda y ambiente sano*
egen miss_dim4_ind1=rowmiss(hsize vi07)
egen miss_dim4_ind2=rowmiss(vi03a vi03b vi04a vi04b vi05a vi05b)
egen miss_dim4_ind3=rowmiss(vi09)
egen miss_dim4_ind4=rowmiss(vi13)

egen miss_total=rowtotal(miss_dim*)
recode miss_total (1/max=1)
label var miss_total "Total de hogares sin informacin"

drop miss_dim*
drop if p03==99
tempvar aux
bys id_hogar: egen `aux'=max(miss_total)
replace miss_total=`aux'
drop if miss_total==1

*===================================================================================*
* C. ESTRUCTURA DE PONDERACIN
*===================================================================================*

# delimit ;
mat pesos=(1/4*1/3,1/4*1/3,1/4*1/3,
		   1/4*1/3,1/4*1/3,1/4*1/3,
		   1/4*1/2,1/4*1/2,
		   1/4*1/4,1/4*1/4,1/4*1/4,1/4*1/4) ;
# delimit cr;		   
svmat double pesos, names(wdim)
foreach var of varlist wdim* {
replace `var'=`var'[_n-1] if _n>1
}

local n2=1
foreach var of varlist dim*_h {
gen wp_`var'=`var'*wdim`n2++'
}

egen ci=rsum(wp_*)
label var ci "Vector de conteo"
*===================================================================================*
* D. LINEAS DE POBREZA MULTIDIMENSIONAL Y COMPONENTES DEL IPM
*===================================================================================*
gen 		TPM  =(ci>=4/12)
gen 		TPEM =(ci>=6/12)
gen 		A   =ci 		if TPM==1
gen 		IPM =0 
replace 	IPM =ci 		if TPM==1 

label var 	TPM  "Tasa de Pobreza Multidimensional (k>=1/3)"
label var 	TPEM "Tasa de Pobreza Extrema Multidimensional (k>=1/2)"
label var 	A    "Porcentaje Promedio de Privaciones (k>=1/3)"
label var 	IPM  "͍ndice de Pobreza Multidimensional (k>=1/3)"

keep TPM TPEM A IPM id_per
save `bddf', replace

use `bdd1', clear
merge 1:1 id_per using `bdd3', keepusing(dim*_p) keep(1 3) nogen
merge 1:1 id_per using `bddf', keep(1 3) nogen
order id_*, first

*===================================================================================*
*                                     FIN
*===================================================================================*
